==> cms-db_v0.6.tar.gz: admin/sudo-gui.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


function sudo_gui($section) {
	include('locale.inc.php');
	$locale = new LocalizingClass('nopermission');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('pagetitle',false,$locale) ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>
		<h1><?php locale('pagetitle',false,$locale) ?></h1>
		<p><?php locale('desc_nopermission',false,$locale) ?></p>
		<p><?php locale('desc_changeuser',false,$locale) ?></p>
		<form action="sudo.php<?php echo SID ?>" method="post">
			<input type="hidden" name="url" value="<?php echo $_SERVER['REQUEST_URI'] ?>" />
			<table style="background: #eee; color: #000; border: 1px solid #aaa; padding: 1em">
				<tr>
					<td rowspan="3">
						<img src="key.png" width="64" height="64" alt="" />
					</td>
					<td>
						<?php locale('label_username',false,$locale) ?>
					</td>
					<td>
						<select name="username" size="1">
							<?php
							if ($handle = opendir('../data/users')) {
								while (false !== ($file = readdir($handle))) {
									if(is_file('../data/users/'.$file) && user_has_rights($file, $section)) {
										include('../data/users/'.$file);
										echo '<option value="'.$user.'">'.$user.'</option>';
									}
								}
								closedir($handle);
							}
							?>
						</select>
					</td>
				</tr>
				<tr>
					<td>
						<?php locale('label_password',false,$locale) ?>
					</td>
					<td>
						<input type="password" name="password" value="" />
					</td>
				</tr>
				<tr>
					<td>&nbsp;</td>
					<td>
						<input type="submit" value="<?php locale('button_changeuser',false,$locale) ?>" />
					</td>
				</tr>
			</table>
		</form>
	</body>
</html>
<?php
}
?>

==> cms-db_v0.7.9.tar.gz: admin/sudo-gui.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


function sudo_gui($section) {
	include('locale.inc.php');
	$locale = new LocalizingClass('nopermission');
	$path = (strpos($_SERVER['SCRIPT_NAME'], '/update/index.php') === false) ? './' : '../';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('pagetitle',false,$locale) ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="<?php echo $path ?>style.css">
	</head>
	<body>
		<h1><?php locale('pagetitle',false,$locale) ?></h1>
		<p><?php locale('desc_nopermission',false,$locale) ?></p>
		<p><?php locale('desc_changeuser',false,$locale) ?></p>
		<form action="<?php echo $path ?>sudo.php<?php echo SID ?>" method="post">
			<input type="hidden" name="url" value="<?php echo $_SERVER['REQUEST_URI'] ?>" />
			<table style="background: #eee; color: #000; border: 1px solid #aaa; padding: 1em">
				<tr>
					<td rowspan="3">
						<img src="<?php echo $path ?>key.png" width="64" height="64" alt="" />
					</td>
					<td>
						<?php locale('label_username',false,$locale) ?>
					</td>
					<td>
						<select name="username" size="1">
							<?php
							if ($handle = opendir('../data/users')) {
								while (false !== ($file = readdir($handle))) {
									if(is_file('../data/users/'.$file) && user_has_rights($file, $section)) {
										include('../data/users/'.$file);
										echo '<option value="'.$user.'">'.$user.'</option>';
									}
								}
								closedir($handle);
							}
							?>
						</select>
					</td>
				</tr>
				<tr>
					<td>
						<?php locale('label_password',false,$locale) ?>
					</td>
					<td>
						<input type="password" name="password" value="" />
					</td>
				</tr>
				<tr>
					<td>&nbsp;</td>
					<td>
						<input type="submit" value="<?php locale('button_changeuser',false,$locale) ?>" />
					</td>
				</tr>
			</table>
		</form>
	</body>
</html>
<?php
}
?>
